@@ -9,16 +9,18 @@ from rpy.functions.decorators import to_tuple
 from rpy.functions.functional import first, iterate
 
 
-async def wait_all(args, **opts):
-    done = tuple(iterate(args))
-    if done:
-        done, _ = await asyncio.wait(done, **opts)
-        return tuple(map(methodcaller('result'), done))
+async def _id(id, task):
+    return id, await task
 
+async def wait_all(*args):
+    done = tuple(_id(i, t) for i, t in enumerate(iterate(*args)))
+    if done:
+        futures, p = await asyncio.wait(done)
+        futures = dict(map(methodcaller('result'), futures))
+        return tuple(futures[i] for i in range(len(done)))
     return done
 
-
-def run_all(args, **opts):
+def run_all(*args, **opts):
     done = tuple(iterate(*args))
     if done and len(done) > 1:
         return asyncio.ensure_future(asyncio.wait(done), **opts)
@@ -36,6 +38,8 @@ def get_event_loop(loop=None):
         return loop
 
 
+
+
 @to_tuple
 def syncronous_wait_all(*args, loop=None):
     yield from (loop or get_event_loop()).run_until_complete(wait_all(*args))
